@@ -17,6 +17,9 @@
 # CAM签名/鉴权错误。
 AUTHFAILURE = 'AuthFailure'
 
+# 访问鉴权失败。
+AUTHFAILURE_ACCESSCAMFAIL = 'AuthFailure.AccessCAMFail'
+
 # 请求未授权。请参考 CAM 文档对鉴权的说明。
 AUTHFAILURE_UNAUTHORIZEDOPERATION = 'AuthFailure.UnauthorizedOperation'
 
@@ -35,9 +38,15 @@ FAILEDOPERATION_ACCESSTKEFAIL = 'FailedOperation.AccessTKEFail'
 # 访问标签服务失败。
 FAILEDOPERATION_ACCESSTAGFAIL = 'FailedOperation.AccessTagFail'
 
+# agent当前状态不允许该操作。
+FAILEDOPERATION_AGENTNOTALLOWED = 'FailedOperation.AgentNotAllowed'
+
 # Agent版本不支持该操作，请升级Agent。
 FAILEDOPERATION_AGENTVERSIONNOTSUPPORTED = 'FailedOperation.AgentVersionNotSupported'
 
+# 该实例上有正在运行的Agent。
+FAILEDOPERATION_AGENTSNOTINUNINSTALLSTAGE = 'FailedOperation.AgentsNotInUninstallStage'
+
 # 删除过滤条件失败。
 FAILEDOPERATION_ALERTFILTERRULEDELETEFAILED = 'FailedOperation.AlertFilterRuleDeleteFailed'
 
@@ -59,6 +68,12 @@ FAILEDOPERATION_ALERTTRIGGERRULEDELETEFAILED = 'FailedOperation.AlertTriggerRule
 # Yaml 格式不正确。
 FAILEDOPERATION_BADYAMLFORMAT = 'FailedOperation.BadYamlFormat'
 
+# 创建实例失败。
+FAILEDOPERATION_CREATEINSTANCE = 'FailedOperation.CreateInstance'
+
+# 该账号创建实例被限制。
+FAILEDOPERATION_CREATEINSTANCELIMITED = 'FailedOperation.CreateInstanceLimited'
+
 # 数据表字段不存在。
 FAILEDOPERATION_DATACOLUMNNOTFOUND = 'FailedOperation.DataColumnNotFound'
 
@@ -104,15 +119,27 @@ FAILEDOPERATION_DUPLICATENAME = 'FailedOperation.DuplicateName'
 # 生成资源ID错误。
 FAILEDOPERATION_GENERATEINSTANCEIDFAILED = 'FailedOperation.GenerateInstanceIDFailed'
 
+# 实例不存在。
+FAILEDOPERATION_INSTANCENOTFOUND = 'FailedOperation.InstanceNotFound'
+
 # 实例没有运行。
 FAILEDOPERATION_INSTANCENOTRUNNING = 'FailedOperation.InstanceNotRunning'
 
+# 内部服务错误。
+FAILEDOPERATION_INTERNALERROR = 'FailedOperation.InternalError'
+
+# 地区不可用。
+FAILEDOPERATION_REGIONUNAVAILABLE = 'FailedOperation.RegionUnavailable'
+
 # 资源已经存在。
 FAILEDOPERATION_RESOURCEEXIST = 'FailedOperation.ResourceExist'
 
 # 资源不存在。
 FAILEDOPERATION_RESOURCENOTFOUND = 'FailedOperation.ResourceNotFound'
 
+# 资源正在被操作。
+FAILEDOPERATION_RESOURCEOPERATING = 'FailedOperation.ResourceOperating'
+
 # 发送授权请求失败。
 FAILEDOPERATION_SENDREQUEST = 'FailedOperation.SendRequest'
 
@@ -128,6 +155,9 @@ FAILEDOPERATION_TKEENDPOINTSTATUSERROR = 'FailedOperation.TKEEndpointStatusError
 # 更新TKE资源时出现冲突。
 FAILEDOPERATION_TKERESOURCECONFLICT = 'FailedOperation.TKEResourceConflict'
 
+# 可用区不可用。
+FAILEDOPERATION_ZONEUNAVAILABLE = 'FailedOperation.ZoneUnavailable'
+
 # 内部错误。
 INTERNALERROR = 'InternalError'
 
